#include <iostream>
#include <algorithm>
#include <cmath>
#include <cassert>
#include <queue>

using ll = long long;

int const nmax = 600;
ll const inf = 2000000000;

class Graph{
private:
  struct Edge{
    int to;
    int rev;
    int flow;
    int cap;
    int cost;
  };
  std::vector<std::vector<Edge>> g;
  std::vector<ll> dist, dist2;
  std::vector<int> in_stack, prev;
  int source, sink, n;
public:
  Graph(int _n) {
    n = _n;
    g.resize(1 + n);
    dist.resize(1 + n);
    dist2.resize(1 + n);
    in_stack.resize(1 + n);
    prev.resize(1 + n);
    source = 1;
    sink = n;
  }
  void addEdge(int x, int y, int cap, int cost) {
    g[x].push_back({y, g[y].size(), 0, cap, cost});
    g[y].push_back({x, g[x].size() - 1, 0, 0, -cost});
  }
  void setSourceSink(int x, int y) {
    source = x;
    sink = y;
  }

  void bellman() {
    std::queue<int> q;

    std::fill(in_stack.begin(), in_stack.end(), 0);
    std::fill(dist.begin(), dist.end(), inf);
    q.push(1);
    dist[source] = 0;
    in_stack[source] = 1;

    while(0 < q.size()) {
      int node = q.front();
      in_stack[node] = 0;
      q.pop();
      for(int h = 0; h < g[node].size(); h++) {
        Edge &e = g[node][h];
        if(e.flow < e.cap && dist[node] + e.cost < dist[e.to]) {
          dist[e.to] = dist[node] + e.cost;
          if(in_stack[e.to] == 0) {
            q.push(e.to);
            in_stack[e.to] = 1;
          }
        }
      }
    }
  }
  
  std::pair<int, ll> dijkstra() {
    std::priority_queue<std::pair<ll,int>,
                        std::vector<std::pair<ll,int>>,
                        std::greater<std::pair<ll,int>>>
                        pq;
    std::fill(dist2.begin(), dist2.end(), inf);
    dist2[source] = 0;
    pq.push({0, source});
    while(0 < pq.size()) {
      ll cost = pq.top().first;
      int node = pq.top().second;
      pq.pop();
      if(dist2[node] != cost)
        continue;
      for(int h = 0; h < g[node].size(); h++) {
        Edge &e = g[node][h];
        if(e.flow < e.cap && dist2[node] + e.cost - dist[e.to] + dist[node] < dist2[e.to]) {
          dist2[e.to] = dist2[node] + e.cost - dist[e.to] + dist[node];
          prev[e.to] = e.rev;
          pq.push({dist2[e.to], e.to});
        }
      }
    }
    if(dist2[sink] < inf) {
      ll delta = inf;
      int target = sink;
      while(target != source) {
        int newtarget = g[target][prev[target]].to;
        delta = std::min(delta, 1LL * g[newtarget][g[target][prev[target]].rev].cap - 
                                g[newtarget][g[target][prev[target]].rev].flow);
        target = newtarget;
      }

      std::pair<int, ll> result;
      result.first = delta;
      result.second = 0;
      target = sink;

      while(target != source) {
        int newtarget = g[target][prev[target]].to;
        result.second += 1LL * delta * g[newtarget][g[target][prev[target]].rev].cost;
        g[target][prev[target]].flow -= delta;
        g[newtarget][g[target][prev[target]].rev].flow += delta;
        target =newtarget;
      }
      
      for(int i = 1;i <= n; i++) {
        dist[i] += dist2[i];
        if(inf < dist[i])
          dist[i] = inf;
      }
      return result;
    }
    return {0, 0};
  }

  std::pair<int,ll> maxflow() {
    bellman();
    std::pair<int, ll> result = {0, 0}, acc = {0, 0};
    do {
      result.first += acc.first;
      result.second += acc.second;
      acc = dijkstra();
    } while(0 < acc.first);
    return result;
  }
};
int l[5 + nmax], r[5 + nmax];

void testGraph() {
  int n, m;
  std::cin >> n >> m;
  Graph graph(n);
  for(int i = 1; i <= m; i++) {
    int x, y, cap, cost;
    std::cin >> x >> y >> cap >> cost;
    graph.addEdge(x, y, cap, cost);
  }
  std::pair<int, ll> answer = graph.maxflow();
  std::cout << answer.first << " " << answer.second << '\n';
}

int main() {
  int n, k;
  std::cin >> n >> k;
  Graph graph(2 * n + 4);
  graph.setSourceSink(2 * n + 1, 2 * n + 2);
  for(int i = 1;i <= n; i++)
    std::cin >> l[i] >> r[i];
  for(int i = 1;i <= n; i++)
    graph.addEdge(n + i, 2 * n + 2, 1, 0);
  graph.addEdge(n * 2 + 1, n * 2 + 3, k, 0);
  graph.addEdge(n * 2 + 1, n * 2 + 4, n - k, 0);
  for(int i = 1;i <= n; i++)
    graph.addEdge(n * 2 + 3, n + i, 1, 0);
  
  for(int i = 1;i <= n; i++)
    graph.addEdge(n * 2 + 4, i, 1, 0);
  
  for(int i = 1; i <= n; i++)
    for(int j = i + 1; j <= n; j++)
      graph.addEdge(i, n + j, 1, std::abs(r[i] - l[j]));
  
  std::pair<int, ll> result = graph.maxflow();
  assert(result.first == n);
  std::cout << result.second << '\n';
  return 0;
}
